<?php

require("../../include/variables.php");
require("../../include/init.php");

if (isset($_SESSION['userID']) ==  false || empty($_SESSION['userID'])) {
    header("Location: /login?p=adhesion");
    die('Veuillez vous connecter dans <a href="/login">/login</a>');
}

require("../../include/main-functions.php");
require("../../include/inputs.php");
require("../../include/panels.php");

$pdo = sqlConnect($sqlDatabaseHost, $sqlDatabaseName, $sqlDatabaseUser, $sqlDatabasePass);

$userID = $_SESSION['userID'];

$sql = "SELECT etape_adhesion FROM adherents WHERE userid = :userid";
$stepStmt = $pdo->prepare($sql);
$stepStmt->bindParam(":userid", $userID);
$stepStmt->execute();
$stepResult = $stepStmt->fetchAll(PDO::FETCH_ASSOC);
$step = $stepResult[0]['etape_adhesion'];

if (isset($_POST['lastname']) && isset($_POST['firstname']) && isset($_POST['email']) && isset($_POST['club']) && isset($_POST['born']) && $step == 0) {
    if ($_POST['valide'] != "accepte") {
        $status = "Vous devez vous engager à restpecter les statuts et le règlement intérieur";
    } else {
        if (empty($_POST['lastname']) || empty($_POST['firstname']) || empty($_POST['email']) || empty($_POST['born'])) {
            $status = "Veuillez remplir tous les champs";
        } else {
            if (preg_match('/^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/', $_POST['email']) == false) {
                $status = "Veuillez entrer un email valide";
            } else {
                $email = isset($_POST['email']) ? strtolower($_POST['email']) : NULL;
                $lastname = htmlspecialchars($_POST['lastname']);
                $firstname = htmlspecialchars($_POST['firstname']);
                $club = empty($_POST['club']) ? "Sans club" : htmlspecialchars($_POST['club']);
                $born = htmlspecialchars($_POST['born']);
                $promo = empty($_POST['promo']) ? "Sans promo" : htmlspecialchars($_POST['promo']);
    
                $sqlRequest = "SELECT ID FROM adherents WHERE userid = :userid";
                $request = $pdo->prepare($sqlRequest);
                $request->bindParam(":userid", $userID);
                $request->execute();
                $result = $request->fetchAll(PDO::FETCH_ASSOC);
    
                if($result) {
                    $requestAlreadySent = true;
                } else {
                    $requestAlreadySent = false;
                    $request = $pdo->prepare("INSERT INTO adherents (firstname, lastname, born, promo, club, email, userid) VALUES (:firstname, :lastname, :born, :promo, :club, :email, :userid)");
                    $request->bindParam(':firstname', $firstname);
                    $request->bindParam(':lastname', strtoupper($lastname));
                    $request->bindParam(':born', $born);
                    $request->bindParam(':promo', $promo);
                    $request->bindParam(':club', $club);
                    $request->bindParam(':email', $email);
                    $request->bindParam(':userid', $userID);
    
                    if ($request->execute()) {
                        $status = "Demande d'adhésion envoyée, vous recevrez la réponse du CA par mail.";

                        $from = "no-reply@e59.fr";
                        $fromName = "Association E59";
                        $to = "communication@e59.fr";
                        $subject = "Nouvelle demande d'adhésion";
                        $body = "$firstname $lastname a fait une demande d'adhésion";
                        $altbody = "$firstname $lastname a fait une demande d'adhésion";

                        sendMail($from, $fromName, $to, $subject, $body, $altbody);
                    } else {
                        $status = "Erreur SQL";
                    }
                }
            }
        }
    }
}

$checkColor = "#99D366";
$pendingColor = "#878787";

?>

<!DOCTYPE html>
<html lang="fr">

    <head>
        <?php fillHead($rootPageURL, "Adhésion - " . $pageName, $darkTheme, $lightTheme);?>
        <style>
            .select-input {
                margin: 0.5em auto 1.5em auto;
                width: 80%;
                font-size: 0.8em;
            }
            .date-input {
                margin: 0.5em auto;
                font-size: 0.8em;
                width: 80%;
            }
            #avancement-adhesion {
                margin: 0.5em;
            }
            #avancement-adhesion circle {
                margin: 1em;
                fill: none;
                stroke-width: 6px;
                stroke-miterlimit: 10;
            }
            #avancement-adhesion line {
                margin: 1em;
                fill: none;
                stroke-width: 6px;
                stroke-miterlimit: 10;
                stroke-linecap: round;
            }
            #avancement-adhesion polyline {
                stroke-linejoin: round;
                stroke-linecap: round;
                fill: none;
                stroke-width: 6px;
            }
            #avancement-adhesion text {
                font-family: "Inter", Arial;
                font-size: 30px;
            }
            .step-1 {
                <?php if ($step >= 0) {echo ('stroke: ' . $checkColor);} else {echo ('stroke: ' . $pendingColor);}?>  
            }
            .step-2 {
                <?php if ($step >= 2) {echo ('stroke: ' . $checkColor);} else {echo ('stroke: ' . $pendingColor);}?>  
            }
            .step-3 {
                <?php if ($step >= 3) {echo ('stroke: ' . $checkColor);} else {echo ('stroke: ' . $pendingColor);}?>     
            }
            .step-check-1 {
                <?php if ($step >= 0) {echo ('stroke: ' . $checkColor);} else {echo ('display: none;');}?>  
            }
            .step-check-2 {
                <?php if ($step >= 2) {echo ('stroke: ' . $checkColor);} else {echo ('display: none;');}?>  
            }
            .step-check-3 {
                <?php if ($step >= 3) {echo ('stroke: ' . $checkColor);} else {echo ('display: none;');}?>  
            }
            .step-text-1 {
                <?php if ($step >= 0) {echo ('fill: ' . $checkColor);} else {echo ('fill: ' . $pendingColor);}?>
            }
            .step-text-2 {
                <?php if ($step >= 2) {echo ('fill: ' . $checkColor);} else {echo ('fill: ' . $pendingColor);}?>
            }
            .step-text-3 {
                <?php if ($step >= 3) {echo ('fill: ' . $checkColor);} else {echo ('fill: ' . $pendingColor);}?>
            }
            .adv-box {
                border: 1px solid var(--text);
                border-radius: 10px;
                width: 7em;
                font-size: 0.8em;
                text-align: center;
                padding: 0.5em;
            }
            h2 {
                text-align: center;
            }
            .member-info {
                width: 100%;
                display: flex;
                justify-content: center;
            }
            #Calque_1 {
                width: 40%;
                margin-top: 1em;
            }
            @media(max-width: 750px) {
                #Calque_1 {
                    width: 100%;
                }
            }
        </style>
    </head>

    <body class="body">

        <header>
            <div class="panel-content">
                <?php fillHeader($rootPageURL, $headerTitle, $headerSubtitle, $social);?>
            </div>
        </header>

        <nav>
            <div class="panel-content">
                <?php fillNav($rootPageURL);?>
            </div>
        </nav>

        <main>
            <div class="content">
                <?php
                    if ($step == 0) {
                        echo ('<form action="#" method="post">');
                        echo ('<div class="form">');
                        echo ('<div class="form-title">Adhésion</div>');
                        echo ('<div class="status"><?=$status?></div>');

                        $sqlRequest = "SELECT username, email FROM users WHERE ID = :userID";
                        $request = $pdo->prepare($sqlRequest);
                        $request->bindParam(":userID", $_SESSION['userID']);
                        $request->execute();
                        $user = $request->fetchAll(PDO::FETCH_ASSOC);

                        $sqlRequest = "SELECT ID, name FROM clubs";
                        $request = $pdo->prepare($sqlRequest);
                        $request->execute();
                        $clubs = $request->fetchAll(PDO::FETCH_ASSOC);

                        $clubOptions = array();

                        foreach($clubs as $club) {
                            $clubOptions[$club["ID"]] =  $club["name"];
                        }

                        textInput("text", "", "lastname", "Nom", isset($_POST['lastname']) ? $_POST['lastname'] : "");
                        textInput("text", "", "firstname", "Prénom",  isset($_POST['firstname']) ? $_POST['firstname'] : "");
                        textInput("email", "", "email", "Email",  isset($_POST['email']) ? $_POST['email'] : $user[0]['email']);
                        textInput("text", "", "promo", "Promo (exemple: BUT RT3)",  isset($_POST['promo']) ? $_POST['promo'] : "");
                        selectInput("club", "Club", $clubOptions, isset($_POST['club']) ? $_POST['club'] : $clubOptions[0]);
                        dateInput("born", "Né le", "1930-01-01", isset($_POST['born']) ? $_POST['born'] : "2005-01-01");
                        echo ('<div style="margin: 2em 0;""><input type="checkbox" name="valide" value="accepte">');
                        echo ('<label for="valide" style="font-size: 0.6em; margin-left: 0.5em;">Je m\'engage à respecter les <a href="https://e59.fr/about/docs/pdf/Statuts-E59-UVSQ.pdf" target="_blank">statuts</a> et le <a href="https://e59.fr/about/docs/pdf/Reglement-Interieur-E59-UVSQ.pdf" target="_blank">règlement intérieur</a></label></div>');
                        echo ('<a href="/" class="hidden-button" style="margin-right: 2em;">Annuler</a><button type="submit">Envoyer</button>');
                        echo ('</div>');
                        echo ('</form>');
                    } else if ($step == 3){
                        $adherentID = $_SESSION['userID'];
                        //$adherentID = 3;
                        $sqlRequest = "SELECT adherents.ID, adherents.firstname, adherents.lastname, adherents.email, clubs.name, adherents.memberid, adherents.join_date FROM adherents JOIN clubs ON adherents.club = clubs.ID WHERE adherents.userid = :userID";
                        $request = $pdo->prepare($sqlRequest);
                        $request->bindParam(":userID", $adherentID);
                        $request->execute();
                        $result = $request->fetchAll(PDO::FETCH_ASSOC);
                        echo ('<h2>Votre carte membre</h2>');
                        echo ('<div class="member-info">');
                        echo ('<svg id="Calque_1" data-name="Calque 1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 963.76 612.27">');
                        echo ('<defs><style>');
                        echo ('.cls-1 {fill: url(#e59-logos);}');
                        echo ('.cls-1, .cls-2, .cls-3, .cls-4 {stroke-width: 0px;}');
                        echo ('.cls-5 {letter-spacing: .02em;}');
                        echo ('.cls-6 {font-size: 30px;}');
                        echo ('.cls-6, .cls-7, .cls-4, .cls-8 {fill: #fff;}');
                        echo ('.cls-6, .cls-8 {font-family: cfont, cfont;font-variation-settings: "wght" 400, "wdth" 100;}');
                        echo ('.cls-9 {stroke: #010101;}');
                        echo ('.cls-9, .cls-2 {fill: none;}');
                        echo ('.cls-9, .cls-10 {stroke-miterlimit: 10;}');
                        echo ('.cls-3 {fill: #0c0d0d;}');
                        echo ('.cls-7 {font-size: 20px;font-variation-settings: "wght" 300, "wdth" 100;font-weight: 300;}');
                        echo ('.cls-11 {letter-spacing: -.04em;}');
                        echo ('.cls-12 {letter-spacing: 0em;}.cls-13 {letter-spacing: -.02em;}');
                        echo ('.cls-14 {letter-spacing: 0em;}.cls-8 {font-size: 60px;}');
                        echo ('.cls-15 {letter-spacing: -.03em;}');
                        echo ('.cls-16 {letter-spacing: -.01em;}');
                        echo ('.cls-10 {fill: url(#Dégradé_sans_nom_10);stroke: #1d1d1b;stroke-width: .5px;}');
                        echo ('.cls-17 {letter-spacing: .04em;}');
                        echo ('.cls-18 {letter-spacing: -.05em;}');
                        echo ('</style>');
                        echo ('<radialGradient id="Dégradé_sans_nom_10" data-name="Dégradé sans nom 10" cx="481.88" cy="306.13" fx="481.88" fy="306.13" r="569.3" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#333334"/><stop offset="1" stop-color="#0c0d0d"/></radialGradient><pattern id="e59-logos" x="0" y="0" width="34.02" height="33.45" patternTransform="translate(-615.78 -.5)" patternUnits="userSpaceOnUse" viewBox="0 0 34.02 33.45">');
                        echo ('<g><rect class="cls-2" y="0" width="34.02" height="33.45"/>');
                        echo ('<g><path class="cls-3" d="M32.9,30.03v6.84c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27v-5.55c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM31.34,29.77c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94v4.44c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94v-4.44Z"/><path class="cls-3" d="M29.78,29.78l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16v1.88c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0l-2.73-1.53c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17v1.89c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M15.9,30.03v6.84c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27v-5.55c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM14.33,29.77c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94v4.44c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94v-4.44Z"/><path class="cls-3" d="M12.77,29.78l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16v1.88c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0l-2.73-1.53c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17v1.89c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M41.41,13.3v6.84c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27v-5.55c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM39.84,13.05c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94v4.44c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94v-4.44Z"/><path class="cls-3" d="M38.29,13.06l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16v1.88c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0l-2.73-1.53c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17v1.89c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M24.4,13.3v6.84c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27v-5.55c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM22.83,13.05c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94v4.44c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94v-4.44Z"/><path class="cls-3" d="M21.28,13.06l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16v1.88c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0l-2.73-1.53c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17v1.89c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M7.39,13.3v6.84c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16L-.4,24.2c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44L.27,23.17c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27v-5.55c0-1.11.54-2.13,1.39-2.62L-1.1,7.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM5.83,13.05c0-.4-.19-.76-.5-.94L.4,9.25c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94v4.44c0,.4.19.76.5.94L-.4,21.28c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94v-4.44Z"/><path class="cls-3" d="M4.27,13.06l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22L0,12.3l1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31L-.45,15.52c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16v1.88c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0l-2.73-1.53c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17v1.89c0,.22.11.42.28.51L-.22,19.75c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M32.9-3.42V3.42c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0l-5.55-3.22-1.42-.83c-.09-.05-.14-.16-.14-.27V-3.42c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM31.34-3.68c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94V.76c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94V-3.68Z"/><path class="cls-3" d="M29.78-3.67l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16V-.52c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0L22.64-.11c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17V.24c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0l4.05-2.27c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('<g><path class="cls-3" d="M15.9-3.42V3.42c0,1.11-.54,2.13-1.39,2.62l-4.91,2.84c-.69.4-1.51.4-2.2,0l-5.12-2.97c-.36-.21-.65-.52-.85-.91-.2-.38-.32-.83-.32-1.3,0-.13.12-.22.22-.16l6.78,3.93c.25.14.54.14.79,0l5.2-3.01c.07-.04.13-.11.17-.18.04-.08.06-.17.06-.26,0-.37-.33-.6-.61-.44l-4.95,2.87c-.17.1-.37.1-.54,0L2.68,3.23l-1.42-.83c-.09-.05-.14-.16-.14-.27V-3.42c0-1.11.54-2.13,1.39-2.62l4.91-2.84c.69-.4,1.51-.4,2.2,0l4.91,2.84h0c.85.49,1.39,1.51,1.39,2.62ZM14.33-3.68c0-.4-.19-.76-.5-.94l-4.93-2.86c-.25-.14-.54-.14-.79,0l-4.93,2.86c-.31.18-.5.54-.5.94V.76c0,.4.19.76.5.94l4.93,2.86c.25.14.54.14.79,0l4.93-2.86c.31-.18.5-.54.5-.94V-3.68Z"/><path class="cls-3" d="M12.77-3.67l-1.04-.58c-.09-.05-.19-.05-.27,0l-1.32.74-1.38.78c-.16.09-.34.09-.5,0l-1.19-.67c-.08-.04-.08-.17,0-.22l1.44-.81,1.17-.66c.12-.07.12-.26,0-.33l-.94-.53c-.14-.08-.3-.08-.44,0l-4.05,2.28s0,0,0,0c-.11.06-.11.25,0,.31l3.82,2.15c.28.16.61.16.9,0l2.42-1.36c.1-.06.22.03.22.16V-.52c0,.18-.09.33-.22.41l-2.72,1.53c-.09.05-.2.05-.29,0L5.63-.11c-.13-.07-.22-.23-.22-.4v-.52c0-.07-.04-.14-.09-.17l-1.13-.63c-.11-.06-.24.03-.24.17V.24c0,.22.11.42.28.51l4.05,2.27c.14.08.3.08.44,0L12.77.75c.17-.1.28-.3.28-.51v-3.39c0-.22-.11-.42-.28-.51h0Z"/></g>');
                        echo ('</g></pattern></defs>');
                        echo ('<path class="cls-10" d="M963.76,37.54v537.19c0,2.83-.31,5.58-.91,8.23-.67,3.02-1.71,5.89-3.06,8.58-.99,1.98-2.16,3.86-3.48,5.62-.84,1.14-1.76,2.23-2.73,3.26-3.94,4.21-8.85,7.51-14.37,9.54-4.05,1.5-8.42,2.31-12.99,2.31H37.53c-4.65,0-9.11-.85-13.22-2.4-5.49-2.06-10.37-5.38-14.28-9.6-.77-.83-1.5-1.7-2.19-2.59-1.36-1.74-2.56-3.61-3.59-5.58-1.49-2.84-2.61-5.88-3.33-9.09-.6-2.66-.92-5.43-.92-8.28V37.54c0-3.65.52-7.18,1.49-10.51,1.68-5.78,4.71-10.98,8.72-15.23.09-.1.19-.2.29-.3.35-.37.72-.74,1.1-1.1C16.31,5.9,22.19,2.61,28.74,1.04,31.56.36,34.5,0,37.53,0h888.69c2.94,0,5.8.34,8.54.98,6.57,1.52,12.48,4.78,17.22,9.26,1.46,1.38,2.81,2.87,4.02,4.46.12.14.22.28.32.42,2.65,3.54,4.68,7.56,5.95,11.91.97,3.33,1.49,6.86,1.49,10.51Z"/>');
                        echo ('<g><path class="cls-1" d="M517.03,418.51c.47-16.51-44.79-8.22-57.13-8.83-3.7.47-8.83.89-8.41,5.26,0,15.63-21.62,21.28-17.75,37.56,34.92-20.2,69.8-16.53,104.58.41-1.62-22.64-18.17-21.87-21.3-34.39Z"/>');
                        echo ('<path class="cls-1" d="M473.38,400.84c7.94,4.43,17.75,3.27,25.56-1.48,19.88-12.1,39.15,1.75,58.9,3.45-10.96-20.93-32.63-34.39-53.16-45.64,11.55-12.59,31.8-17.83,30.7-37.99-.32-2.38-8-2.64-11.37-5.02-22.46-19.74-57.97-19.88-80.16.47-33.93,5.2,8.55,33.93,21.79,42.9-15.67,7.51-28.26,16.75-39.77,27.29h0c-2.74,4.81-6.78,8.41-11.33,11.55h0c-7.13,17.38,36.51-13.68,58.86,4.45l-.02.02Z"/>');
                        echo ('<path class="cls-1" d="M963.76,567.56v7.17c0,2.83-.31,5.58-.91,8.23-.67,3.02-1.71,5.89-3.06,8.58l-279.56-29.65,283.53,5.67Z"/>');
                        echo ('<path class="cls-1" d="M969.75-.68l-.03.04.02.02.03-.04s-.01-.02-.02-.02ZM963.76,37.54c0-3.65-.52-7.18-1.49-10.51-1.27-4.35-3.3-8.37-5.95-11.91l-120.16,139.46c-.14-2.15-.32-4.31-.57-6.4L956,14.7c-1.21-1.59-2.56-3.08-4.02-4.46-4.74-4.48-10.65-7.74-17.22-9.26C932.02.34,929.16,0,926.22,0h-14.58l-84.88,112.04c-.57-1.46-1.16-2.9-1.77-4.36L910.51,0h-51.27l-51.34,77.44c-.75-1.05-1.53-2.13-2.32-3.18L857.3,0h-46.2l-19,32.98c-.43-1.28-.85-2.52-1.3-3.76L808.54,0h-103.03c6.95,7.43,13.7,15.26,20.71,22.75-17.13-3.08-29.93-13.08-43.01-22.75h-59.63c6.47,3.34,13.46,5.94,21.2,7.46-24.18,5.4-48.91,1.84-71.86-7.46h-61.7c21.29,18.82,48.26,29.86,79.85,35.09-34.67,13.54-70.71.33-94.16-30.7l-.63-.87c-.85-1.15-1.69-2.32-2.49-3.52h-19.19c-.53.86-1.07,1.72-1.63,2.56l-.39.59c-20.1,29.69-58.41,44.93-93.05,32.63C410.21,30.56,436.52,19.16,457.61,0h-62.89c-24.25,9.53-50.55,13.1-76.71,8.23C327.58,6.68,336.07,3.79,343.85,0h-58.73c-13.89,10.39-27.1,21.6-45.1,21.49C248.71,15.04,256.15,7.49,263.5,0h-102.63l17.53,28.9c-.44,1.24-.87,2.48-1.28,3.73L158.32,0h-46.21l51.57,74.05c-.79,1.04-1.56,2.12-2.33,3.15L110.17,0h-51.27l85.33,107.45c-.61,1.42-1.22,2.89-1.79,4.35L57.76,0h-20.23C34.5,0,31.56.36,28.74,1.04c-6.55,1.57-12.43,4.86-17.14,9.36-.38.36-.75.73-1.1,1.1l123.05,136.42c-.24,2.11-.45,4.2-.59,6.35L10.21,11.8c-4.01,4.25-7.04,9.45-8.72,15.23C.52,30.36,0,33.89,0,37.54v26.66l129.37,126.46c-.96,1.58-1.85,3.14-2.72,4.73L0,65.81v55.23l117.31,101.07c-.37,2.25-.61,4.51-.73,6.8L0,123.74v48.23l123.83,93.81c-.49,2.36-.94,4.69-1.3,7.03L0,175.5v42.77l119.95,79.53c-.08,2.74-.1,5.44,0,8.12L0,222.39v38.42l123.34,71.06c.89,3.49,1.93,6.92,3.19,10.27L0,265.35v34.95l144.41,71.51c3.84,4.28,8.19,8.32,13.08,12.14.32,1.46.67,2.88,1.05,4.3L0,305.18v32.2l165.61,69.43c2.54,5,5.58,9.56,9.1,13.69L0,342.52v29.99l225.08,78.14c1.26,4.46,2.82,8.75,4.67,12.87L0,377.83v28.27l233.55,64.97c2.86,5.1,6.17,9.85,9.86,14.25L0,411.58v26.97l248.75,52.62c6.72,6.74,14.42,12.43,22.76,16.92L0,444.13v25.94l276.71,40.59c12.96,6.01,27.27,9.28,41.95,9.32.06,1.06.12,2.11.16,3.11.63,17.5-2.66,25.14-10.98,37.7-1.18,2.12-2.46,4.17-3.84,6.2-18.88.81-38.27,4.54-58.15,10.92l-238.01,19.77c.69.89,1.42,1.76,2.19,2.59,3.91,4.22,8.79,7.54,14.28,9.6,4.11,1.55,8.57,2.4,13.22,2.4h29.09l158.99-27.05c-11.41,4.57-22.99,9.93-34.68,16.02l-75.21,11.03h82.78c22.99-11.91,47.58-20.01,72.16-32.63-2.15,16.53-10.61,25.48-21.81,32.63h400.47c.32-.99.63-1.98.94-2.97.71.18,1.42.43,2.19.61.11.79.23,1.58.34,2.36h75.92c-10-5.55-19.56-11.45-23-24.01-.45-1.68-.55-3.38-.91-6.21,25.08,10.4,48.98,20.31,72.84,30.22h76.64l-76.29-11.19c-11.74-6.12-23.33-11.5-34.78-16.04l160.05,27.23h22.96c4.57,0,8.94-.81,12.99-2.31,5.52-2.03,10.43-5.33,14.37-9.54.97-1.03,1.89-2.12,2.73-3.26l-233.2-19.37c-19.84-6.36-39.21-10.07-58.05-10.89-1.36-2.01-2.64-4.06-3.82-6.13-8.3-12.54-11.61-20.2-10.98-37.6.04-1.05.1-2.13.16-3.27,14.6-.04,28.85-3.27,41.79-9.24l271.55-39.83v-25.44l-266.5,62.78c8.43-4.49,16.18-10.22,22.95-16.98l243.55-51.52v-26.44l-238.23,72.18c3.71-4.41,7.06-9.18,9.92-14.28l228.31-63.52v-27.74l-224.53,83.73c1.85-4.1,3.41-8.41,4.69-12.89l219.84-76.33v-29.46l-169.65,75.72c3.57-4.14,6.64-8.73,9.22-13.77l160.43-67.25v-31.61l-153.33,80.34c.43-1.46.8-2.96,1.14-4.5,4.79-3.72,9.04-7.68,12.79-11.84l139.4-69.03v-34.3l-121.31,73.63c1.26-3.37,2.34-6.81,3.21-10.32l118.1-68.03v-37.73l-114.63,79.83c.09-2.68.06-5.38,0-8.12l114.63-75.99v-42.02l-117.14,93.04c-.39-2.34-.84-4.67-1.32-7.03l118.46-89.74v-47.41l-111.24,100.36c-.12-2.29-.34-4.56-.71-6.84l111.95-96.44v-54.3l-121.18,123.98c-.86-1.58-1.75-3.17-2.7-4.75l123.88-121.1v-32.16ZM795.02,81.02c.27,2.7.61,5.4.86,8.1-1,.47-2.72,1.32-2.97,1.32-20.24-30.01-56.58-34.17-88.36-47.05,33.56-12.66,79.77.11,90.47,37.63ZM790.03,134.64c-24.34,5.03-42.07-11.21-62.56-18.42-8.79-5.62-14.72-16.64-25.46-18.41-4.56-7.41-44.89-10.48-33.92-16.93v-.02c56.03-25.28,77.09,38.82,121.94,53.78ZM744.18,84.71c-31.47-28.42-69.76-28.3-107.97-17.72h-.02l-1.06-.33-.81.65c-12.32-1.64-24.93,5.34-37.66-.65,74.84-41.72,141.37-15.06,147.52,18.05ZM371.57,66.35c-4.37,6.51-13.74,2.87-20.38,3.26-2.12-2.05-4.71-2.01-7.35-1.65-29.18-2.86-60.55-14.7-87.43-.63-13.69,3.58-24.35,13.16-36.95,19.82,3.87-18.19,33.15-36.14,59.87-41.48,32.76-1.58,63.85,3.86,92.24,20.68ZM306.82,81.91c-46.27,7.96-71.83,51.96-117.96,50.96-.35-.85-.39-1.74-.16-2.66,39.73-20.81,65.48-73.82,118.12-48.3ZM266.8,41.22c-31.55,17.77-71.71,16.75-90.94,51.88-4.02-47.74,51.19-61.06,90.94-51.88ZM131.72,212.61c8.43,19.53,23.35,33.74,39.96,46.69,2.68,2.1,9.08,3.23.33,7.54-6.76,3.33,5.46,7.81,2.11,13.01v.02c-25.52-6.76-42.78-32.28-44.65-66.43.71-.33,1.48-.59,2.25-.83ZM205.55,362.37c-48.47,18.07-77.36-40-71-81.38,26.59,32.32,44.75,79.53,93.31,74.07-6.54,8.06-14.19,4.73-22.31,7.31ZM216.55,215.57c4.04,3.39,7.43,6.23,12.81,10.74l-.02.02c-20-.53-35.69-8.32-52.32-13.16-1.05,7.54,6.56,10.52,6.56,16.55-22.35-3.06-33.52-17.3-37.36-47.49,1.63-3.08-1.87-7.63,2.97-9.83,21.6,38.38,66.88,29.57,105.82,25.67-11.45,11.75-25.46,12.46-38.46,17.5ZM200.27,171.59v.02c-4.71-1.72-9.4-3.47-14.09-5.22,4.22-2.25,9.07.23,12.85-2.84,32.1-1.28,58.35-24.1,85.86-37.72-12.58,35.61-47.22,49.62-84.62,45.76ZM636.76,316.19c-2.68,34.16-6.66,69.57-22.28,101.28-25.15,74.66-120.7,86.07-188.78,65.28-66.96-21.14-86.25-99.67-88.3-160.36.04-8.43-6.58-9.12-11.17-12.12-26.76-17.46-30.23-49.26-8.02-68.18v.02c6.05-6.2,11.62-7.45,20.16-2.44,31.43,18.21,66.15-.59,96.71-11.35,15.84-9.87,17.87,47.71,18.74,57.97,22.17-.49,13.67-95.25,8.51-112.48-14.01-57.85-128.58-36.9-155.49,3.43,6.83-30.42,22.97-50.56,40.69-74.01,6.09-3.59,13.42-4.45,19.17-7.63,1.05.22,1.89-.05,2.41-.94,39.07-12.93,77.73-26.76,109.42-53.58,4.89-4.2,7.23-4.51,12.28-.1,36.88,32.38,82.56,46.98,129.18,59.63,9.32,10.38,16.63,22.48,25.38,32.75,2.31,5.97,26.98,48.14,5.58,31.02-34.41-27.53-128.1-44.54-143.06,8.39-4.61,18.92-13.48,112.46,9.93,114.9,5.89-87.31,2.03-56.81,70.39-41.46,28.08,10.66,51.07-25.38,71.47,1.58,24.97,22.6,3.15,55.76-22.92,68.4ZM694.05,143.76c.27-6.38-9.38-9.32-6.19-16.67,29.93,17.97,56.59,36.44,93.74,38.72-31.59,12.04-69.92,7.53-87.55-22.05ZM742.17,226.33c4.55-2.96,9.06-5.97,16.41-10.74-20.39-3.59-36-8.79-50.9-19.49h11.23c39.32,13.4,80.01,4.93,101.68-21.69.77,2.89,1.44,5.36,2.13,7.84-1.16,2.09-1.32,4.16-.14,6.28-2.12,16.93-11.42,38.86-32.35,37.01,1.12-4.02,2.16-8.04,3.62-13.58-16.61,7.35-33.06,12.42-51.68,14.37ZM763.76,361.92c-7.21-.98-13.02.38-18.91-5.93,45.48.04,67.23-41.78,89.48-75.83v19.55c3.7,40.16-34.21,77.34-70.57,62.21ZM797.67,279.19s.01.02.01.03l-.02-.02h.01c-1.57-4.5,2.84-7.34,2.92-11.29-2.91-3.1-6.91,1.65-10.17-1.15,18.03-16.02,35.34-32.27,47.45-53.36,7.85,22.41-9.26,50.69-40.2,65.79ZM969.75-.68l-.03.04.02.02.03-.04s-.01-.02-.02-.02Z"/>');
                        echo ('<polygon class="cls-1" points="289.08 537.28 0 531.5 0 506.62 289.08 537.28"/>');
                        echo ('<polygon class="cls-1" points="963.76 476.59 963.76 501.37 679.05 525.02 963.76 476.59"/>');
                        echo ('<polygon class="cls-1" points="288.69 549.57 0 561.95 0 537.19 288.69 549.57"/>');
                        echo ('<polygon class="cls-1" points="963.76 537.45 963.76 561.73 680.65 549.59 963.76 537.45"/>');
                        echo ('<path class="cls-1" d="M289.08,561.89L4.25,592.1c-1.49-2.84-2.61-5.88-3.33-9.09-.6-2.66-.92-5.43-.92-8.28v-7.06l289.08-5.78Z"/>');
                        echo ('<polygon class="cls-1" points="290.23 525.02 0 500.91 0 475.65 290.23 525.02"/>');
                        echo ('<polygon class="cls-1" points="963.76 507.21 963.76 531.61 680.23 537.28 963.76 507.21"/></g>');
                        echo ('<path class="cls-9" d="M926.22,612.27c20.73,0,37.54-16.81,37.54-37.54V37.54C963.76,16.81,946.95,0,926.22,0H37.53C16.8,0,0,16.81,0,37.54v537.19c0,20.73,16.8,37.54,37.53,37.54h888.69Z"/>');
                        echo ('<text class="cls-8" transform="translate(100 329.51)"><tspan x="0" y="0">' . $result[0]['firstname'] . ' ' . $result[0]['lastname'] . '</tspan></text>');
                        echo ('<text class="cls-6" transform="translate(100 408.13)"><tspan x="0" y="0">' . $result[0]['email'] . '</tspan></text>');
                        echo ('<text class="cls-7" transform="translate(51.04 585.77)"><tspan x="0" y="0">' . $result[0]['name'] . '</tspan></text>');
                        echo ('<text class="cls-6" transform="translate(820 60)"><tspan x="0" y="0">' . $result[0]['memberid'] . '</tspan></text>');
                        echo ('<text class="cls-7" transform="translate(821.2 587.24)"><tspan x="0" y="0">' . $result[0]['join_date'] . '</tspan></text>');
                        echo ('<g><g><path class="cls-4" d="M79.67,41.13l-15.97-9.26c-2.26-1.31-4.9-1.31-7.16,0l-15.97,9.26c-2.76,1.6-4.51,4.91-4.51,8.53v18.08c0,.37.18.72.47.88l4.63,2.68h0l18.08,10.48c.56.32,1.21.32,1.77,0l16.1-9.33c.91-.53,1.97.25,1.97,1.44h0c0,.61-.3,1.17-.76,1.44l-16.91,9.8c-.81.47-1.76.47-2.57,0l-22.06-12.79c-.33-.19-.71.09-.71.52h0c0,3.05,1.47,5.83,3.8,7.18l16.68,9.67c2.26,1.31,4.9,1.31,7.16,0l15.97-9.26c2.76-1.6,4.51-4.91,4.51-8.53v-22.27c0-3.62-1.75-6.92-4.51-8.53h0ZM79.08,63.27c0,1.3-.63,2.49-1.62,3.06l-16.05,9.31c-.81.47-1.76.47-2.57,0l-16.05-9.31c-.99-.58-1.62-1.76-1.62-3.06v-14.44c0-1.3.63-2.49,1.62-3.06l16.05-9.31c.81-.47,1.76-.47,2.57,0l16.05,9.31c.99.58,1.62,1.76,1.62,3.06v14.44Z"/><path class="cls-4" d="M74.02,48.86l-3.39-1.9c-.28-.16-.61-.16-.89,0l-4.31,2.42-4.5,2.53c-.51.29-1.11.29-1.63,0l-3.86-2.17c-.26-.15-.26-.57,0-.71l4.68-2.63,3.8-2.13c.39-.22.39-.85,0-1.07l-3.07-1.73c-.46-.26-.99-.26-1.45,0l-13.17,7.41s0,0,0,0c-.37.21-.36.82,0,1.02l12.44,6.99c.92.52,2,.52,2.92,0l7.86-4.42c.34-.19.73.09.73.52v6.13c0,.57-.28,1.09-.73,1.34l-8.86,4.98c-.29.16-.64.16-.93,0l-8.88-4.99c-.43-.24-.71-.75-.71-1.3v-1.68c0-.23-.12-.45-.3-.55l-3.68-2.06c-.36-.2-.78.1-.78.55v6.16c0,.71.35,1.36.91,1.67l13.17,7.4c.46.26.99.26,1.45,0l13.17-7.4c.56-.31.91-.96.91-1.67v-11.03c0-.71-.35-1.36-.91-1.67h0Z"/></g>');
                        echo ('<g><polygon class="cls-4" points="100.59 41.31 97.81 41.31 97.81 82.11 100.59 82.11 105.5 82.11 125.15 82.11 125.15 74.7 105.5 74.7 105.5 65.55 122.06 65.55 122.06 58.14 105.5 58.14 105.5 48.72 125.15 48.72 125.15 41.31 105.5 41.31 100.59 41.31"/><path class="cls-4" d="M145.27,54.1c-.97,0-1.96.16-2.96.48-1,.32-1.8.77-2.4,1.35v-7.21h14.23v-7.41h-21.92v23.46h7.18c.3-1.01.84-1.8,1.61-2.36.78-.56,1.72-.84,2.82-.84,1.22,0,2.15.44,2.81,1.3.65.87.98,2.11.98,3.72v3.42c0,1.59-.37,2.83-1.11,3.72-.74.89-1.78,1.33-3.13,1.33-1.24,0-2.24-.42-3-1.25s-1.23-2-1.37-3.49v-.03h-7.69v.03c.26,3.87,1.5,6.88,3.72,9.01,2.22,2.13,4.96,3.2,8.24,3.2,3.84,0,6.8-1.09,8.9-3.27,2.1-2.18,3.14-5.26,3.14-9.25v-3.42c0-3.97-.87-7.04-2.62-9.22-1.75-2.18-4.22-3.27-7.42-3.27h0Z"/><path class="cls-4" d="M182.53,44.18c-2.08-2.2-5.01-3.3-8.81-3.3s-6.74,1.09-8.83,3.27-3.13,5.25-3.13,9.22v.03c0,3.61.95,6.51,2.85,8.69,1.9,2.18,4.4,3.27,7.51,3.27,1.01,0,1.91-.13,2.73-.38l-7.5,17.13h8.14l7.3-17.48c.8-1.93,1.48-3.84,2.03-5.74.55-1.9.83-3.68.83-5.35v-.03c0-4.02-1.04-7.13-3.11-9.33h0ZM177.96,53.18c0,1.59-.37,2.82-1.11,3.69-.74.87-1.78,1.3-3.13,1.3s-2.42-.43-3.16-1.29-1.11-2.09-1.11-3.68v-.03c0-1.53.37-2.72,1.11-3.56s1.79-1.26,3.16-1.26,2.39.42,3.13,1.25c.74.83,1.11,2.02,1.11,3.55v.03h0Z"/></g></g></svg>');
                        echo ('</div>');
                    } else {
                        echo ('<div class="form">');
                        echo ('<div class="form-title">Adhésion</div>');
                        echo ('<div class="status"><?=$status?></div>');
                        echo ('<svg id="avancement-adhesion" data-name="Avancement Adhésion" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 621.85 174.92"><defs></defs><circle class="step-1" cx="65.07" cy="136.34" r="34.92"/><circle class="step-2" cx="308.65" cy="136.34" r="34.92"/><circle class="step-3" cx="552.24" cy="136.34" r="34.92"/><line class="line step-2" x1="248.28" y1="136.34" x2="125.44" y2="136.34"/><line class="step-3" x1="491.87" y1="136.34" x2="369.03" y2="136.34"/><polyline class="step-check-1" points="50.66 139.2 61.81 149.72 79.48 128.34"/><polyline class="step-check-2" points="294.24 139.2 305.4 149.72 323.07 128.34"/><polyline class="step-check-3" points="537.83 139.2 548.99 149.72 566.65 128.34"/><text class="step-text-1" transform="translate(-2.64 22.37)"><tspan x="0" y="0">Demande</tspan><tspan x="8.39" y="36">envoyée</tspan></text><text class="step-text-2" transform="translate(241.34 22.37)"><tspan x="0" y="0">Demande</tspan><tspan class="cls-10" x="17.39" y="36">validée</tspan></text><text class="step-text-3" transform="translate(480.33 22.5)"><tspan x="0" y="0">Cotisation</tspan><tspan x="29.08" y="36">payée</tspan></text></svg>');
                        if ($step == 2) {
                            echo ('<a class="button" href="/pay?type=2&article=1">Payer la cotisation</a>');
                        }
                        echo ('</div>');
                    }
                ?>
            </div>
        </main>
        <footer>
            <div class="panel-content">
                <?php fillFooter($footerText);?>
            </div>
        </footer>
    </body>
</html>